@@ -1,5 +1,8 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional
 from unittest import TestCase as BaseTestCase, TestSuite
+from unittest.loader import TestLoader
+
+from sybil.example import Example
 
 if TYPE_CHECKING:
     from ..sybil import Sybil
@@ -7,16 +10,17 @@ if TYPE_CHECKING:
 
 class TestCase(BaseTestCase):
 
-    sybil = namespace = None
+    sybil: 'Sybil'
+    namespace: Dict[str, Any]
 
-    def __init__(self, example):
+    def __init__(self, example: 'Example') -> None:
         BaseTestCase.__init__(self)
         self.example = example
 
-    def runTest(self):
+    def runTest(self) -> None:
         self.example.evaluate()
 
-    def id(self):
+    def id(self) -> str:
         return '{},line:{},column:{}'.format(
             self.example.path, self.example.line, self.example.column
         )
@@ -24,19 +28,25 @@ class TestCase(BaseTestCase):
     __str__ = __repr__ = id
 
     @classmethod
-    def setUpClass(cls):
+    def setUpClass(cls) -> None:
         if cls.sybil.setup is not None:
             cls.sybil.setup(cls.namespace)
 
     @classmethod
-    def tearDownClass(cls):
+    def tearDownClass(cls) -> None:
         if cls.sybil.teardown is not None:
             cls.sybil.teardown(cls.namespace)
 
 
-def unittest_integration(*sybils: 'Sybil'):
+def unittest_integration(
+    *sybils: 'Sybil',
+) -> Callable[[Optional[TestLoader], Optional[TestSuite], Optional[str]], TestSuite]:
 
-    def load_tests(loader=None, tests=None, pattern=None):
+    def load_tests(
+        loader: Optional[TestLoader] = None,
+        tests: Optional[TestSuite] = None,
+        pattern: Optional[str] = None,
+    ) -> TestSuite:
         suite = TestSuite()
         for sybil in sybils:
             for path in sorted(sybil.path.glob('**/*')):
